# BonziSEND

![example](https://raw.githubusercontent.com/prankapple/BonziCONNECT/main/Docs/example.png?raw=true)

A Python library that lets you interact with BonziBuddy via BonziCONNECT.

> ⚠️ **Windows Only**
>  
> This library only works on **Windows** because it depends on `BonziCONNECT.exe`.
> It will **not run on macOS or Linux**.


## Requirements
You must download and run **BonziCONNECT.exe** before using this library.

Download it here:  
[BonziCONNECT.exe](https://github.com/prankapple/BonziCONNECT/tree/main/BonziCONNECT)

Run `BonziCONNECT.exe` before starting your Python script.

---

## Installation

Install the Python library from pip:

```bash
pip install BonziSEND
```

# Usage

Import the library using this :
```python
import BonziSEND
```

## Speak
Use :
```python
BonziSEND.speak("Hello from Python")
```

## Play animation
Use :
```python
BonziSEND.play("Wave")
```

